@@ -1,6 +1,6 @@
 #!/bin/bash
 
-RELEASE_NAME=2.x
+RELEASE_NAME=v2.3
 
 UPSTREAM="https://github.com/solvespace/solvespace.git"
 git clone --depth=1 --recursive -b ${RELEASE_NAME} ${UPSTREAM}
@@ -10,7 +10,7 @@ rm -rfv solvespace/extlib/libpng
 rm -rfv solvespace/extlib/zlib
 rm -rfv solvespace/extlib/si
 rm -rfv solvespace/debian
-rm -rfv solvespace/.git
+rm -rfv solvespace/.gi*
 rm -rfv solvespace/.travis
 rm -rfv solvespace/src/fonts/unifont-8.0.01.hex.gz
 
